@@ -63,6 +63,11 @@ class InitConnectionPool:
                         clazz = InitConnectionPool.getClass("lesscode.db.redis.redis_pool", fromlist="RedisPool")
                         # 执行用例
                         pool = clazz(conn_info).create_pool()
+                    elif conn_info.dialect == "neo4j":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.neo4j.neo4j_pool", fromlist="Neo4jPool")
+                        # 执行用例
+                        pool = await clazz(conn_info).create_pool()
                     if pool:
                         options.database[conn_info.name] = (pool, conn_info.dialect)
 
@@ -111,6 +116,11 @@ class InitConnectionPool:
                         clazz = InitConnectionPool.getClass("lesscode.db.redis.redis_pool", fromlist="RedisPool")
                         # 执行用例
                         pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "neo4j":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.neo4j.neo4j_pool", fromlist="Neo4jPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
                     if pool:
                         options.database[conn_info.name] = (pool, conn_info.dialect)
 
